summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
commit73ff676f11662d6178c8854a7832ebffe2ae409d (patch)
tree9e89ea7d87940087d2d3c5db9b378ef989dd1346 /lib/kofficecore/KoDocument.h
parentc2ba2f56121c21a762619faf195e8332ef5b224f (diff)
downloadkoffice-73ff676f11662d6178c8854a7832ebffe2ae409d.tar.gz
koffice-73ff676f11662d6178c8854a7832ebffe2ae409d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'lib/kofficecore/KoDocument.h')
-rw-r--r--lib/kofficecore/KoDocument.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index 63fd47c9..30b9ad97 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -188,7 +188,7 @@ public:
* @see KService
* @see KDesktopFile
*/
- static TQCString readNativeFormatMimeType( KInstance *instance = 0 );
+ static TQCString readNativeFormatMimeType( TDEInstance *instance = 0 );
/**
* Used by KoMainWindow, when no document exists yet.
@@ -200,14 +200,14 @@ public:
* @see KService
* @see KDesktopFile
*/
- static TQStringList readExtraNativeMimeTypes( KInstance *instance = 0 );
+ static TQStringList readExtraNativeMimeTypes( TDEInstance *instance = 0 );
/**
* With the help of @p instance or TDEApplication::instance() this
* method figures out which .desktop file matches this application,
* and returns the KService instance for it.
*/
- static KService::Ptr readNativeService( KInstance *instance = 0 );
+ static KService::Ptr readNativeService( TDEInstance *instance = 0 );
/**
* setup the XML reader, so that we don't have to duplicate the code.
@@ -1123,11 +1123,11 @@ protected:
/**
* Creates the open widget showed at application start up.
* @param parent the parent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
* @since 1.5
*/
- KoOpenPane* createOpenPane( TQWidget* parent, KInstance* instance,
+ KoOpenPane* createOpenPane( TQWidget* parent, TDEInstance* instance,
const TQString& templateType = TQString());
private slots:
@@ -1123,11 +1123,11 @@ protected:
* Creates the open widget showed at application start up.
* @param parent the parent widget
- * @param instance the KInstance to be used for KConfig data
+ * @param instance the TDEInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
* @since 1.5